==> hypervehicle-0.6.0.tar.gz: hypervehicle-0.6.0/README.md <==
[![x43](docs/source/images/logo-dark.png)](docs/hangar.md)

<p align="center">
  
  <a href="https://pypi.org/project/hypervehicle/">
    <img src="https://img.shields.io/pypi/v/hypervehicle?color=blue&style=plastic" alt="Latest version" width=95 height=20>
  </a>
  
  <a href="https://github.com/psf/black">
    <img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">
  </a>

  <a>
    <img src="https://github.com/kieran-mackle/hypervehicle/actions/workflows/tests.yml/badge.svg" alt="Test Status" class="center">
  </a>
  
</p>

A Python package to rapidly generate parametric geometries
defined by hyperpatches. Check out the 
[hangar](docs/source/hangar.md) for some examples.


## Installation

To install `hypervehicle` from [PyPI](https://pypi.org/project/hypervehicle/), use the command below.

```
pip install hypervehicle
```

### Developing HyperVehicle
Contributions to HyperVehicle are welcome. Please refer to the [contribution guidelines](https://hypervehicle.readthedocs.io/en/latest/other/contributing.html) for guidance.


## Citing HyperVehicle
If you use HyperVehicle in any published work, please cite it using the BibTex reference below.

```text
@inproceedings{Mackle2024,
  author    = {Mackle, Kieran and Jahn, Ingo},
  booktitle = {AIAA Science and Technology Forum and Exposition},
  title     = {Efficient and Flexible Methodology for the Aerodynamic Shape Optimisation of Hypersonic Vehicle Concepts in a High-Dimensional Design Space},
  year      = {2024},
}
```

## License
HyperVehicle is licensed under [GPLv3](COPYING).

==> hypervehicle-0.7.1.tar.gz: hypervehicle-0.7.1/README.md <==
[![x43](docs/source/images/logo-dark.png)](docs/hangar.md)

<p align="center">
  
  <a href="https://pypi.org/project/hypervehicle/">
    <img src="https://img.shields.io/pypi/v/hypervehicle?color=blue&style=plastic" alt="Latest version" width=95 height=20>
  </a>
  
  <a href="https://github.com/psf/black">
    <img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">
  </a>

  <a href="https://kieran-mackle.github.io/hypervehicle/pytest_report">
    <img src="https://github.com/kieran-mackle/hypervehicle/actions/workflows/tests.yml/badge.svg" alt="Test Status" >
  </a>

  <a href="https://kieran-mackle.github.io/hypervehicle/coverage">
    <img src="https://github.com/kieran-mackle/hypervehicle/raw/gh-pages/coverage.svg?raw=true" alt="Test Coverage" >
  </a>
  
</p>

A Python package to rapidly generate parametric geometries
defined by hyperpatches. Check out the 
[hangar](docs/source/hangar.md) for some examples.


## Installation

To install `hypervehicle` from [PyPI](https://pypi.org/project/hypervehicle/), use the command below.

```
pip install hypervehicle
```

### Developing HyperVehicle
Contributions to HyperVehicle are welcome. Please refer to the [contribution guidelines](https://hypervehicle.readthedocs.io/en/latest/other/contributing.html) for guidance.


## Citing HyperVehicle
If you use HyperVehicle in any published work, please cite it using the BibTex reference below.

```text
@inproceedings{Mackle2024,
  author    = {Mackle, Kieran and Jahn, Ingo},
  booktitle = {AIAA Science and Technology Forum and Exposition},
  title     = {Efficient and Flexible Methodology for the Aerodynamic Shape Optimisation of Hypersonic Vehicle Concepts in a High-Dimensional Design Space},
  year      = {2024},
}
```

## License
HyperVehicle is licensed under [GPLv3](COPYING).
